@@ -19,11 +19,6 @@ def list_apps():
     pass
 
 
-@app.route('/query/active-app')
-def active_app():
-    pass
-
-
 @app.route('/query/icon/<app_id>')
 def app_icon(app_id):
     pass
